// Core modules
let Shell = require('shell');
let Remote = require('remote');
let Dialog = Remote.require('dialog');
let App = Remote.require('app');

// Our modules
let KonamiCodeManager = require('./modules/KonamiCodeManager');
let AutoUpdater = require('./modules/AutoUpdater');
let AppMenus = require('./modules/AppMenus');
let $ = require('jquery');

// We need to make sure all views would be executed after needed DOMs
// are prepared.
$(document).ready(() => {
  require('./views/toolbar');
  require('./views/webview');
  AppMenus.build();

  // This is mainly for debugging use, if our developer pass the Konami code
  // The menu items will be changed and the developer tool will be shown.
  KonamiCodeManager.attach(document.body, () => {
    AppMenus.rebuild();
  });

  // check update
  AutoUpdater.checkUpdate().then(function(release) {
    if (release) {
      Dialog.showMessageBox({
        type: 'info',
        title: 'New release',
        message:
          'Detect a new release version ' + release.version + '\n' +
          'Click ok to download it.',
        detail: release.note,
        buttons: ['ok', 'cancel']
      }, function(response) {
        // means ok
        if (response === 0) {
          let downloadLink = '';
          let platform = process.platform;
          let arch = process.arch;

          if (platform.match(/win32/)) {
            downloadLink = release.link.windows;
          }
          else if (platform.match(/darwin/)) {
            downloadLink = release.link.mac;
          }
          else if (platform.match(/linux/)) {
            if (arch == 'ia32') {
              downloadLink = release.link.linux32;
            }
            else if (arch === 'x64') {
              downloadLink = release.link.linux64;
            }
          }

          if (downloadLink) {
            Shell.openExternal(downloadLink);
            // a little delay to quit application
            setTimeout(function() {
              App.quit();
            }, 1000);
          }
          else {
            console.log('Cant find download link for the user');
            console.log('platform - ' + platform + ', arch - ', arch);
          }
        }
      });
    }
  }).catch(function(error) {
    console.log(error);
  });
});
